@@ -491,7 +491,12 @@ static void dcc_rewrite_generic_compiler(char **argv)
     if ((st.st_mode & S_IFMT) == S_IFLNK) {
         /* this is a Debian thing. Fedora just has /usr/bin/cc -> gcc */
         if (strcmp(linkbuf, cpp ? "/etc/alternatives/c++" : "/etc/alternatives/cc") == 0) {
-            ssz = readlinkat(dir, linkbuf, linkbuf, sizeof(linkbuf) - 1);
+            char m[MAXPATHLEN + 1];
+
+            m[0] = '\0';
+            strcpy(m, linkbuf);
+
+            ssz = readlinkat(dir, m, linkbuf, sizeof(linkbuf) - 1);
             linkbuf[ssz] = '\0';
         }
     }
@@ -568,7 +573,7 @@ static int dcc_gcc_rewrite_fqn(char **argv)
         return -ENOMEM;
 
     if ((t = strstr(target_with_vendor, "-pc-"))) {
-        strncpy(newcmd, target_with_vendor, t - target_with_vendor);
+        memcpy(newcmd, target_with_vendor, t - target_with_vendor);
         strcat(newcmd, t + strlen("-pc"));
     } else
         strcpy(newcmd, target_with_vendor);
@@ -589,7 +594,7 @@ static int dcc_gcc_rewrite_fqn(char **argv)
             t = path + strlen(path);
         pathlen = t - path;
         if (*path == '\0')
-            return -ENOENT;
+            break;
         strncpy(binname, path, pathlen);
         binname[pathlen] = '\0';
         strcat(binname, "/");
@@ -604,6 +609,7 @@ static int dcc_gcc_rewrite_fqn(char **argv)
         argv[0] = newcmd;
         return 0;
     } while ((path += pathlen + 1));
+    free(newcmd);
     return -ENOENT;
 }
 
@@ -752,7 +758,7 @@ dcc_build_somewhere(char *argv[],
             /* It's unfortunate that the variable that controls that is in the
              * "host" datastructure, even though in this case it's the client
              * that fails to support it,  but "host" is what gets passed
-             * around in the client code. We are, in essense, throwing away
+             * around in the client code. We are, in essence, throwing away
              * the host's capability to do cpp, so if this code was to execute
              * again (it won't, not in the same process) we wouldn't know if
              * the server supports it or not.
@@ -858,7 +864,7 @@ dcc_build_somewhere(char *argv[],
            (Currently, we send email to an appropriate email address).
         */
         if (getenv("DISTCC_SKIP_LOCAL_RETRY")) {
-            /* dont retry locally. We'll treat the remote failure as
+            /* don't retry locally. We'll treat the remote failure as
                if it was a local one. But if we can't get the failures
                then we need to retry regardless.
             */
