@@ -363,7 +363,7 @@ static int dcc_check_compiler_masq(char *compiler_name)
  *
  * Before this it was possible to execute arbitrary command after connecting
  * to distcc, which is quite a security risk when combined with any local root
- * privledge escalation exploit. See CVE 2004-2687
+ * privilege escalation exploit. See CVE 2004-2687
  *
  * https://nvd.nist.gov/vuln/detail/CVE-2004-2687
  * https://github.com/distcc/distcc/issues/155
@@ -402,8 +402,14 @@ static int dcc_check_compiler_whitelist(char *_compiler_name)
     }
 
     if (faccessat(dirfd, compiler_name, X_OK, 0) < 0) {
-        rs_log_crit("%s not in %s whitelist.", compiler_name, LIBDIR "/distcc");
-        return EXIT_BAD_ARGUMENTS;           /* ENOENT, EACCESS, etc */
+        char *compiler_path = NULL;
+        if (asprintf(&compiler_path, "/usr/lib/distcc/%s", compiler_name) && compiler_path) {
+            if (access(compiler_path, X_OK) < 0) {
+                rs_log_crit("%s not in %s or %s whitelist.", compiler_name, LIBDIR "/distcc", "/usr/lib/distcc");
+                return EXIT_BAD_ARGUMENTS;           /* ENOENT, EACCESS, etc */
+            }
+            free(compiler_path);
+        }
     }
 
     rs_trace("%s in" LIBDIR "/distcc whitelist", compiler_name);
@@ -414,10 +420,11 @@ static int dcc_check_compiler_whitelist(char *_compiler_name)
     int ret = 0;
     if (asprintf(&compiler_path, "%s/distcc/%s", LIBDIR, compiler_name) && compiler_path) {
         if (access(compiler_path, X_OK) < 0) {
+            free(compiler_path);
             /* check /usr/lib/distcc too */
             if (asprintf(&compiler_path, "/usr/lib/distcc/%s", compiler_name) && compiler_path) {
                 if (access(compiler_path, X_OK) < 0) {
-                    rs_log_crit("%s not in %s whitelist.", compiler_name, LIBDIR "/distcc");
+                    rs_log_crit("%s not in %s or %s whitelist.", compiler_name, LIBDIR "/distcc", "/usr/lib/distcc");
                     ret = EXIT_BAD_ARGUMENTS;           /* ENOENT, EACCESS, etc */
                 }
             }
@@ -762,8 +769,10 @@ static int dcc_run_job(int in_fd,
     int i;
     for (i = 0; (a = argv[i]); i++)
         if (strncmp(a, "-fplugin=", strlen("-fplugin=")) == 0 ||
-            strncmp(a, "-specs=", strlen("-specs=")) == 0)
+            strncmp(a, "-specs=", strlen("-specs=")) == 0) {
+            rs_log_warning("-fplugin= and/or -specs= passed, which are insecure and not supported.");
             goto out_cleanup;
+    }
 
     if ((compile_ret = dcc_spawn_child(argv, &cc_pid,
                                        "/dev/null", out_fname, err_fname))
